XIncludeFile "..\..\PureAutoIt.pbi"
UseModule PureAutoIt

Macro PrintFormat(vVar, sFormat, sExplan, iTab = 0)
  msg.s = sFormat + " on " + vVar + #TAB$ + " => "
  CompilerIf TypeOf(vVar) = #PB_Double
    CompilerIf #PB_Compiler_Processor = #PB_Processor_x86
      msg + StringFormat(sFormat, PeekL(@vVar), PeekL(@vVar + 4))
    CompilerElse
      msg + StringFormat(sFormat, PeekQ(@vVar))
    CompilerEndIf
  CompilerElseIf TypeOf(vVar) = #PB_String
    msg + StringFormat(sFormat, @vVar)
  CompilerElse
    msg + StringFormat(sFormat, vVar)
  CompilerEndIf

  If iTab
    msg + #TAB$
  EndIf
  msg + #TAB$ + " ; " + sExplan
  Debug msg
EndMacro

Procedure Example()
  iInt_Unsigned = 43951789
  iInt_Negative = -43951789
  dDouble_Unsigned.d = iInt_Unsigned
  sString_Unsigned.s = Str(iInt_Unsigned)
  Debug "Numeric Formats"

  PrintFormat(iInt_Unsigned, "%d", "standard positive integer with no sign", 1) ; 43951789
  PrintFormat(iInt_Negative, "%d", "standard negative integer with sign", 1) ; -43951789
  PrintFormat(iInt_Unsigned, "%i", "standard integer", 1) ; 43951789
  PrintFormat(iInt_Unsigned, "%09i", "9 digits with leading zero", 1) ; 043951789
  PrintFormat(dDouble_Unsigned, "%e", "scientific notation") ; 4.395179e+007
  PrintFormat(iInt_Unsigned, "%u", "unsigned integer with positive integer", 1) ; 43951789
  PrintFormat(iInt_Negative, "%u", "unsigned integer with negative integer", 1) ; 4251015507
  PrintFormat(dDouble_Unsigned, "%f", "floating point") ; 43951789.000000
  PrintFormat(dDouble_Unsigned, "%.2f", "floating point with 2 digits after decimal point", 1) ; 43951789.00
  PrintFormat(iInt_Unsigned, "%o", "octal", 1) ; 247523255
  PrintFormat(sString_Unsigned, "%s", "string", 1) ; 43951789
  PrintFormat(iInt_Unsigned, "%x", "hexadecimal (lower-case)", 1) ; 29ea6ad
  PrintFormat(iInt_Unsigned, "%X", "hexadecimal (upper-case)", 1) ; 29EA6AD
  PrintFormat(iInt_Unsigned, "%+d", "sign specifier on a positive integer", 1) ; +43951789
  PrintFormat(iInt_Negative, "%+d", "sign specifier on a negative integer", 1) ; -43951789

  sString.s = "string"
  sString_Long.s = "longstring"
  Debug ~"\nString Formats - [ ] used to show beginning/end of string"

  PrintFormat(sString, "[%s]", "standard string", 1) ; [string]
  PrintFormat(sString, "[%10s]", "10 chars right justified with added spaces") ; [    string]
  PrintFormat(sString, "[%-10s]", "10 chars left justified with added spaces") ; [string    ]
  PrintFormat(sString_Long, "[%10.8s]", "right justified but precision 8 so truncated") ; [  longer s]
  PrintFormat(sString_Long, "[%-10.8s]", "left justifed but precision 8 so truncated") ; [longer s  ]
  PrintFormat(sString, "[%010s]", "10 chars with leading zero") ; [0000string]

  Debug ~"\nDate Format - each % uses a new parameter"
  Debug "%02i\%02i\%04i 0n (1, 9, 2013) => " + StringFormat("%02i\%02i\%04i", 1, 9, 2013)
EndProcedure

Example()
